# Jekyll Quickstart

This Quickstart contains Jekyll layouts and includes to structure a simple site, and also includes Bootstrap as a front end framework.

## Installation

Add this line to your Jekyll site's `Gemfile`:

```ruby
gem "jekyll-bootstrap-quickstart"
```

And add this line to your Jekyll site's `_config.yml`:

```yaml
theme: jekyll-bootstrap-quickstart
```

And then execute:

```shell
$ bundle
```

Or install it yourself as:

```shell
$ gem install jekyll-bootstrap-quickstart
```

## Usage

#### Layouts
 - Default
 - Home
 - No CSS / JS (used for Error Page)
 - Page
 - Post

#### Includes
 - Build Version
 - Favicons
 - Post Feed
 - Google Analytics
 - Head Tag (including CSS Imports)
 - Header
 - JS Imports

## Customization

#### Styling

Add custom styles by overriding the `assets/css/main.scss` file. Copy this import statement to include all the Bootstrap and Jekyll Quickstart CSS. To start with a clean slate just leave this out.
```scss
---
---

// Import custom styles and Bootstrap from Sass files

/*! Jekyll Quickstart CSS
* 
*/

/* Show it is fixed to the top */
.fixed-header-body {
  padding-top: 5rem;
}

// Jekyll Minima Syntax Highlighting
@import "minima-syntax-highlighting";

// Import Bootstrap CSS
@import "lib/bootstrap/bootstrap";

```

#### Javascript
Add custom JS to `assets/js.main.js`

#### Favicons
Need to be at `assets/img/favicons/`

## Development

To set up your environment to develop this theme (Assumes macOS):

#### Clone Jekyll Quickstart Repo
[https://bitbucket.org/azaleahill/jekyll-quickstart/](https://bitbucket.org/azaleahill/jekyll-quickstart/)

#### Homebrew
Install Homebrew. [https://brew.sh/](https://brew.sh/)
```shell
$ /usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
```

#### Node, npm, and yarn
This project uses yarn as a package manger, and is also compatible with npm. [https://www.npmjs.com/](https://www.npmjs.com/) [https://yarnpkg.com/](https://yarnpkg.com/)
```shell
$ brew install node
$ brew install yarn
```

#### Ruby
Jekyll is built on Ruby. [https://www.ruby-lang.org/](https://www.ruby-lang.org/)
Install with Homebrew to ensure proper environment variables and permissions.
```shell
$ brew install ruby
```

#### Bundler
Bundler is a Ruby Gem / package dependency manager. [http://bundler.io/](http://bundler.io/)
```shell
$ gem install bundler
```

#### Jekyll
[https://jekyllrb.com/](https://jekyllrb.com/)
```shell
$ gem install jekyll
```

## Project Setup
Run install steps for yarn and Bundler
```shell
$ yarn install
```

## Run App Locally
See package.json for all available scripts. Run the app locally by executing the following:
```shell
$ yarn start
```

Head on over to [http://localhost:2802/](http://localhost:2802/)

This will do the following:
 - Run Jekyll Build
 - Launching a development web server with livereload at http://localhost:2802/
 - Watching and recompiling when chnages are saved

## Build Instructions
See package.json for all available scripts. Build the app for various environments by executing the applicable npm script below:
```shell
$ yarn run build-local
$ yarn run build-stage
$ yarn run build-prod
```

## Deployment
**Requires the s3cmd**
```shell
$ brew install s3cmd
```

See package.json for all available scripts. Deploy the app for various environments by executing the applicable npm script below.
See jekyll-ezdeploy README for more info
```shell
$ yarn run deploy
```

## Contributing

Bug reports and pull requests are welcome on BitBucket at [https://bitbucket.org/azaleahill/jekyll-quickstart/](https://bitbucket.org/azaleahill/jekyll-quickstart/) This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The theme is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
